
--[[
	*** X-KeyPad sample Lua script for Dden Challanger 300

	The audio panel on the Challenger is an odd beast. It does not repond to the
	standard X-Plane audio panel commands particularly for the NAV and ADF radios.
	
	This Lua script uses foured shared integer datarefs to model the audio panel for NAV1, NAV2, ADF1, and ADF2.
	If any of these datarefs are 1 indicating that at least one of those radios are being monitored then the
	voice switch will be set to both so you can hear not only the COM audio but also the morse code from the NAV / ADF radios.
	
	In addition if the NAV / ADF radio is not being monitored it's volume control will be set to zero and if it is being
	monitored the volume control will be set to 100% (1.0)
	
	The script also handles APU Start / Stop, and auto start / stop
	
--]]

	
	if(PLANE_ICAO == "CL30"and PLANE_TAILNUMBER == "N929BR") then

		
		-- These datarefs are for the audio panel
		dataref("VOICE_SWITCH", "cl300/aud_voice_l_sw", "writable")		-- Audio Panel Voice Switch
		dataref("SHARED_0", "SRS/X-KeyPad/SharedInt", "writable",0)		-- NAV1 Audio Monitor
		dataref("SHARED_1", "SRS/X-KeyPad/SharedInt", "writable",1)		-- NAV2 Audio Monitor
		dataref("SHARED_2", "SRS/X-KeyPad/SharedInt", "writable",2)		-- ADF1 Audio Monitor
		dataref("SHARED_3", "SRS/X-KeyPad/SharedInt", "writable",3)		-- ADF2 Audio Monitor
		dataref("NAV1_VOLUME", "cl300/aud_vol_15_l", "writable")		-- NAV1 Audio Volume
		dataref("NAV2_VOLUME", "cl300/aud_vol_16_l", "writable")		-- NAV2 Audio Volume
		dataref("ADF1_VOLUME", "cl300/aud_vol_10_l", "writable")		-- ADF1 Audio Volume
		dataref("ADF2_VOLUME", "cl300/aud_vol_11_l", "writable")		-- ADF2 Audio Volume
		
		-- These are for the Start key
		dataref("SHARED_4","SRS/X-KeyPad/SharedInt", "writable",4)		-- Start Key
		dataref("Left_Engine_RPM","sim/cockpit2/engine/indicators/engine_speed_rpm","readonly",0)
		dataref("Right_Engine_RPM","sim/cockpit2/engine/indicators/engine_speed_rpm","readonly",1)


		-- These are for APU start / stop and bleed air
		dataref("SHARED_5","SRS/X-KeyPad/SharedInt", "writable",5)				-- APU Key
		dataref("APU_SWITCH", "sim/cockpit/engine/APU_switch", "writable")		-- APU Switch
		dataref("APU_RUNNING", "sim/cockpit/engine/APU_running", "readonly")	-- APU State
		dataref("BLEED_LEFT", "cl300/bleed_en_l_h", "writable")	-- Left Engine Bleed State
		dataref("BLEED_RIGHT", "cl300/bleed_en_r_h", "writable")	-- Right Engine Bleed State
		dataref("BLEED_XBLEED", "cl300/bleed_xbleed_h", "writable")	-- Crodd Bleed State



		
		-- Init all the Shared Datarefs
		SHARED_0 = 0
		SHARED_1 = 0
		SHARED_2 = 0
		SHARED_3 = 0
		
		if(Left_Engine_RPM > 75) then
			SHARED_4 = 1
		else
			SHARED_4 = 0
		end

		LAST_SHARED_4 = SHARED_4
		
		SHARED_5 = APU_RUNNING
		LAST_SHARED_5 = SHARED_5
		
		-- Define the functions
		function checkStart()

			if(SHARED_4) ~= LAST_SHARED_4 then
				if(SHARED_4 == 1) then
					command_once("cl300/fast_start")
				else
					command_once("cl300/engines/run_both")
				end
				LAST_SHARED_4 = SHARED_4
			end

		end

		function CheckAPU()
		
			if(SHARED_5 ~= LAST_SHARED_5) then
			
				if(SHARED_5 == 1) then
					APU_SWITCH = 2
				else
					APU_SWITCH = 0
-- If both engines are running and the APU is shut off then
-- configue the bleed air for no cross feed and left and right bleed air enabled
					if(Left_Engine_RPM > 400 and Right_Engine_RPM > 400) then
						BLEED_LEFT = 1
						BLEED_RIGHT = 1
						BLEED_XBLEED = 0
					end
				end
				LAST_SHARED_5 = SHARED_5
			end
		
		end
		
		
		function CheckAudioPanel()
		
			if(SHARED_0 == 1 or SHARED_1 == 1 or SHARED_2 == 1 or SHARED_3 == 1) then
				VOICE_SWITCH = 0
			else
				VOICE_SWITCH = 2
			end
			if(VOICE_SWITCH == 1) then
--				VOICE_SWITCH = 2
			end
			
			if(SHARED_0 == 1) then
				NAV1_VOLUME = 1
			else
				NAV1_VOLUME = 0
			end
			
			if(SHARED_1 == 1) then
				NAV2_VOLUME = 1
			else
				NAV2_VOLUME = 0
			end

			if(SHARED_2 == 1) then
				ADF1_VOLUME = 1
			else
				ADF1_VOLUME = 0
			end
			
			if(SHARED_3 == 1) then
				ADF2_VOLUME = 1
			else
				ADF2_VOLUME = 0
			end
			
		end		


		
		
	
		

		-- Start the flightloop call backs
		do_often("CheckAudioPanel()")
		do_often ("checkStart()")
		do_often ("CheckAPU()")


		
		
	end
	
	
